/*
 * Version: 1.0
 *
 * The contents of this file are subject to the OpenVPMS License Version
 * 1.0 (the 'License'); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.openvpms.org/license/
 *
 * Software distributed under the License is distributed on an 'AS IS' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Copyright 2015 (C) OpenVPMS Ltd. All Rights Reserved.
 */

package org.openvpms.web.component.im.contact;

import org.openvpms.component.business.domain.im.common.IMObject;
import org.openvpms.component.business.domain.im.lookup.Lookup;
import org.openvpms.component.business.service.archetype.helper.IMObjectBean;
import org.openvpms.web.component.im.layout.LayoutContext;
import org.openvpms.web.component.property.Modifiable;
import org.openvpms.web.component.property.ModifiableListener;
import org.openvpms.web.component.property.Property;
import org.openvpms.web.system.ServiceHelper;


/**
 * An editor for <em>contact.location</em> contacts.
 *
 * @author Tim Anderson
 */
public class LocationEditor extends AbstractContactEditor {

    /**
     * Constructs a {@link LocationEditor}.
     *
     * @param object        the object to edit
     * @param parent        the parent object. May be {@code null}
     * @param layoutContext the layout context. May be {@code null}.
     */
    public LocationEditor(IMObject object, IMObject parent, LayoutContext layoutContext) {
        super(object, parent, layoutContext);
        final Property suburb = getProperty("suburb");
        suburb.addModifiableListener(new ModifiableListener() {
            public void modified(Modifiable modifiable) {
                onSuburbChanged((String) suburb.getValue());
            }
        });
    }

    /**
     * Updates the postcode when the suburb changes.
     *
     * @param suburb the suburb
     */
    protected void onSuburbChanged(String suburb) {
        Lookup lookup = ServiceHelper.getLookupService().getLookup("lookup.suburb", suburb);
        Property postCode = getProperty("postcode");
        if (lookup != null) {
            IMObjectBean bean = new IMObjectBean(lookup);
            postCode.setValue(bean.getValue("postCode"));
        } else {
            postCode.setValue(null);
        }
    }
}
